@@ -141,7 +141,7 @@ myMessageOutputFormat(QtMsgType type,
 
 
 Application::Application(int &argc, char **argv, const QString &moduleName)
-  : QApplication{argc, argv}, m_moduleName{moduleName}
+  : QApplication{argc, argv}, m_applicationName{moduleName}
 {
   // We are dealing with massive amounts of numerical data and the best locale
   // for that is "C".
@@ -157,9 +157,9 @@ Application::Application(int &argc, char **argv, const QString &moduleName)
 
   // We now have to perform a number of initialization steps.
 
-  QCoreApplication::setOrganizationName(m_moduleName);
+  QCoreApplication::setOrganizationName(m_applicationName);
   QCoreApplication::setOrganizationDomain("msxpertsuite.org");
-  QCoreApplication::setApplicationName(m_moduleName);
+  QCoreApplication::setApplicationName(m_applicationName);
 
   // The default window icon.
   QString pixmap_file_name = ":/images/icons/32x32/minexpert2.png";
@@ -182,7 +182,7 @@ Application::Application(int &argc, char **argv, const QString &moduleName)
       QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
 
   m_userConfigSettingsDirPath =
-    m_userConfigSettingsDirPath + QDir::separator() + m_moduleName;
+    m_userConfigSettingsDirPath + QDir::separator() + m_applicationName;
 
   m_userConfigSettingsFilePath =
     m_userConfigSettingsDirPath + QDir::separator() + "configSettings.ini";
