@@ -54,7 +54,6 @@
 #include "../nongui/MassDataIntegratorTask.hpp"
 
 
-
 namespace msxps
 {
 namespace minexpert
@@ -417,7 +416,7 @@ BasePlotWnd::createMainMenu()
   ////////////// PLOT WIDGET MANAGEMENT ////////////////////
   ////////////// PLOT WIDGET MANAGEMENT ////////////////////
 
-  mp_plotWidgetManagementMenu = new QMenu("Plot &widget management");
+  mp_plotWidgetManagementMenu = new QMenu("Plot &widget management", this);
   mp_mainMenu->addMenu(mp_plotWidgetManagementMenu);
 
   // An action to allow resizing all the plot widget to the mean size. Useful
@@ -453,7 +452,7 @@ BasePlotWnd::createMainMenu()
   mp_plotWidgetManagementMenu->addAction(mp_resetPlotSizesAct);
 
   QMenu *pin_unpin_plot_widgets_menu_p =
-    new QMenu("&Pin-down/Unpin plot widgets...");
+    new QMenu("&Pin-down/Unpin plot widgets...", this);
   mp_plotWidgetManagementMenu->addMenu(pin_unpin_plot_widgets_menu_p);
 
 
@@ -489,7 +488,8 @@ BasePlotWnd::createMainMenu()
 
   mp_plotWidgetManagementMenu->addSeparator();
 
-  QMenu *remove_plot_widgets_menu_p = new QMenu("Remove plot &widgets...");
+  QMenu *remove_plot_widgets_menu_p =
+    new QMenu("Remove plot &widgets...", this);
   mp_plotWidgetManagementMenu->addMenu(remove_plot_widgets_menu_p);
 
   QAction *remove_pinned_plot_widgets_p =
@@ -979,8 +979,8 @@ BasePlotWnd::integrateToTicIntensity(
   if(!qualified_mass_spectra_count)
     return;
 
-  //qDebug() << "The number of remaining mass spectra:"
-           //<< qualified_mass_spectra_count;
+  // qDebug() << "The number of remaining mass spectra:"
+  //<< qualified_mass_spectra_count;
 
   // Now start the actual integration work.
 
@@ -1504,43 +1504,43 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
   if(!integration)
     qFatal("Programming error.");
 
-  //qDebug() << "Filling-in mass spectra for RT range: " << range_pair.first
-           //<< "-" << range_pair.second;
+  qDebug() << "Filling-in mass spectra for RT range: " << range_pair.first
+           << "-" << range_pair.second;
 
-  //std::size_t added_rt_mass_spectra =
+  std::size_t added_rt_mass_spectra =
     ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
       ->addDataSetQualMassSpectraInsideDtRtRange(range_pair.first,
                                                  range_pair.second,
                                                  *qualified_mass_spectra_sp,
                                                  pappso::DataKind::rt);
 
-  //qDebug() << "Added RT mass spectra:" << added_rt_mass_spectra;
+  qDebug() << "Added RT mass spectra:" << added_rt_mass_spectra;
 
   // Now see if we can remove some mass spectra on the basis of DT values.
 
   // We choose ANY_DT that matches in the widest possible manner all the
   // previous integrations that started with a dt-involving selection (both
-  // mono- and two-dimensionale).
+  // mono- and two-dimensional).
   integration = processing_flow.innermostRange("ANY_DT", range_pair);
 
   // Here, it is not an error not to have any DT integration because not all
   // the mass spectral acquisitions involved ion mobility.
   if(integration)
     {
-      //qDebug()
-        //<< "Detected DT integration, removing mass spectra outside DT range: "
-        //<< range_pair.first << "-" << range_pair.second;
+      qDebug()
+        << "Detected DT integration, removing mass spectra outside DT range: "
+        << range_pair.first << "-" << range_pair.second;
 
-      //std::size_t removed_mass_spectra =
-        //ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
-          //->removeDataSetQualMassSpectraOutsideDtRtRange(
-            //range_pair.first,
-            //range_pair.second,
-            //*qualified_mass_spectra_sp,
-            //pappso::DataKind::dt);
+      std::size_t removed_mass_spectra =
+        ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
+          ->removeDataSetQualMassSpectraOutsideDtRtRange(
+            range_pair.first,
+            range_pair.second,
+            *qualified_mass_spectra_sp,
+            pappso::DataKind::dt);
 
-      //qDebug() << "Number of mass spectra removed on the basis of DT:"
-               //<< removed_mass_spectra;
+      qDebug() << "Number of mass spectra removed on the basis of DT:"
+               << removed_mass_spectra;
     }
 
   // At this point we need to really check which of the remaining spectra are
