@@ -775,9 +775,9 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
   // ProcessingType because that will depend on the kind of data we use for the
   // integration below.
 
-  ProcessingStep *step_p = new ProcessingStep();
+  ProcessingStepSPtr step_sp = std::make_shared<ProcessingStep>();
 
-  step_p->setMzIntegrationParams(
+  step_sp->setMzIntegrationParams(
     local_processing_flow.getDefaultMzIntegrationParams());
 
   // qDebug() << "At integration time, mz integration params"
@@ -797,7 +797,7 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
     vector_of_qualified_mass_spectra;
 
   recordQualifiedMassSpectraToIntegrate(
-    vector_of_qualified_mass_spectra, *step_p, integration_type);
+    vector_of_qualified_mass_spectra, *step_sp, integration_type);
 
   if(!vector_of_qualified_mass_spectra.size())
     return;
@@ -807,7 +807,9 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
 
   // We have finished documenting the flow's step, append it to the processing
   // flow.
-  local_processing_flow.push_back(step_p);
+
+  // Should perform automatically the conversion from non-const to const.
+  local_processing_flow.push_back(step_sp);
 
   // qDebug().noquote() << "Right before integrating, processing flow:"
   //<< local_processing_flow.toString();
