@@ -90,8 +90,8 @@ MsRunReadTask::readMsRunData(MsRunReadTask *ms_run_read_task_p,
   // qDebug() << "reading ms run data from thread:" << QThread::currentThread()
   //<< "and this MsRunReadTask:" << this;
 
-  qDebug() << "Reading MS run data with config:"
-           << ms_run_read_config.toString();
+  qDebug("Reading MS run data with config: %s\n", 
+         ms_run_read_config.toString().toLatin1().data());
 
   const auto start_time = std::chrono::steady_clock::now();
 
