@@ -383,6 +383,65 @@ TaskMonitorCompositeWidget::makeMassSpecDataFileLoaderConnections(
 }
 
 
+void
+TaskMonitorCompositeWidget::makeMsRunProberConnections(
+  MsRunProber *ms_run_prober_p)
+{
+
+  // The integrator might want to set the min/max values of the progress bar
+  connect(ms_run_prober_p,
+          &MsRunProber::setupProgressBarSignal,
+          this,
+          &TaskMonitorCompositeWidget::setupProgressBar);
+
+  // The loader might want to set the min value of the progress bar.
+  connect(ms_run_prober_p,
+          &MsRunProber::setProgressBarMinValueSignal,
+          this,
+          &TaskMonitorCompositeWidget::setProgressBarMinValue);
+
+  // The loader informs by signals of the total number of spectra to be loaded.
+  connect(ms_run_prober_p,
+          &MsRunProber::setProgressBarMaxValueSignal,
+          this,
+          &TaskMonitorCompositeWidget::setProgressBarMaxValue);
+
+  // The loader informs by signals of the number of added mass spectra.
+  connect(ms_run_prober_p,
+          &MsRunProber::setProgressBarCurrentValueSignal,
+          this,
+          &TaskMonitorCompositeWidget::setProgressBarCurrentValue);
+
+  // The loader informs by signals of the loading process with informative text.
+  connect(ms_run_prober_p,
+          &MsRunProber::setStatusTextSignal,
+          this,
+          &TaskMonitorCompositeWidget::setStatusText);
+
+  // In some cases, we want to just append new informative text without erasing
+  // the previous one.
+  connect(ms_run_prober_p,
+          &MsRunProber::appendStatusTextSignal,
+          this,
+          &TaskMonitorCompositeWidget::appendStatusText);
+
+  connect(ms_run_prober_p,
+          &MsRunProber::setStatusTextAndCurrentValueSignal,
+          this,
+          &TaskMonitorCompositeWidget::setStatusTextAndCurrentValue);
+
+  connect(ms_run_prober_p,
+          &MsRunProber::lockTaskMonitorCompositeWidgetSignal,
+          this,
+          &TaskMonitorCompositeWidget::lock);
+
+  connect(ms_run_prober_p,
+          &MsRunProber::unlockTaskMonitorCompositeWidgetSignal,
+          this,
+          &TaskMonitorCompositeWidget::unlock);
+}
+
+
 void
 TaskMonitorCompositeWidget::setTimeLag(double time_lag)
 {
