@@ -52,6 +52,7 @@
 #include "ui_TaskMonitorCompositeWidget.h"
 #include "../nongui/MassDataIntegrator.hpp"
 #include "../nongui/MassSpecDataFileLoader.hpp"
+#include "../nongui/MsRunProber.hpp"
 
 #include "../nongui/QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 
@@ -79,12 +80,14 @@ class TaskMonitorCompositeWidget : public QWidget
   void
   makeMassDataIntegratorConnections(MassDataIntegrator *mass_data_integrator_p);
 
-	void
-  makeMassDataIntegratorConnections(QualifiedMassSpectrumVectorMassDataIntegrator *mass_data_integrator_p);
+  void makeMassDataIntegratorConnections(
+    QualifiedMassSpectrumVectorMassDataIntegrator *mass_data_integrator_p);
 
   void makeMassSpecDataFileLoaderConnections(
     MassSpecDataFileLoader *mass_spec_data_file_loader_p);
 
+  void makeMsRunProberConnections(MsRunProber *ms_run_prober_p);
+
   void setTimeLag(double time_lag);
   double getTimeLag() const;
 
