@@ -179,7 +179,7 @@ void
 TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
   const pappso::BasePlotContext &context)
 {
-  //qDebug().noquote() << "context:" << context.toString();
+  // qDebug().noquote() << "context:" << context.toString();
 
   // We are getting that signal from a plot widget that operates as a
   // tic xic chrom / mass spec color map plot widget. By essence, the selected
@@ -263,8 +263,8 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
   ProcessingFlow local_processing_flow =
     getProcessingFlowForPlottable(plottable_p);
 
-  //qDebug().noquote() << "Processing flow for graph:"
-                     //<< local_processing_flow.toString();
+  // qDebug().noquote() << "Processing flow for graph:"
+  //<< local_processing_flow.toString();
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     getMsRunDataSetCstSPtrForPlottable(plottable_p);
@@ -273,7 +273,7 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
 
   // Create a processing step to document the specifics of this new integration.
 
-  ProcessingStep *processing_step_p = new ProcessingStep();
+  ProcessingStepSPtr processing_step_sp = std::make_shared<ProcessingStep>();
 
   // If the user had set ms fragmentation specifications, all these are listed
   // in the various ProcessingSpec instances, so we do not loose any. However,
@@ -292,7 +292,7 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
       // flow " "is valid, using it:"
       //<< ms_fragmentation_spec.toString();
 
-      processing_step_p->setMsFragmentationSpec(ms_fragmentation_spec);
+      processing_step_sp->setMsFragmentationSpec(ms_fragmentation_spec);
     }
   else
     {
@@ -338,7 +338,7 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
 
   pappso::SelectionPolygon local_selection_polygon = context.m_selectionPolygon;
 
-  //qDebug() << "The selection polygon:" << local_selection_polygon.toString();
+  // qDebug() << "The selection polygon:" << local_selection_polygon.toString();
 
   if(x_axis_data_kind == pappso::DataKind::rt)
     {
@@ -356,31 +356,32 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
 
   // Now we know we have the right selection polygon for x:DT and y:RT.
 
-  processing_step_p->setDataKind(pappso::Axis::x, pappso::DataKind::dt);
-  processing_step_p->setDataKind(pappso::Axis::y, pappso::DataKind::rt);
+  processing_step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::dt);
+  processing_step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::rt);
 
 
   // And now actually set the selection polygon to the step.
 
-  processing_step_p->setSelectionPolygon(local_selection_polygon);
+  processing_step_sp->setSelectionPolygon(local_selection_polygon);
 
   // qDebug() << "Selection polygon as set to the step:"
   //<< processing_step_p->getSelectionPolygon().toString();
 
   // We must say what is the data source processing type.
-  processing_step_p->setSrcProcessingType(pappso::Axis::x, "DT");
-  processing_step_p->setSrcProcessingType(pappso::Axis::y, "RT");
+  processing_step_sp->setSrcProcessingType(pappso::Axis::x, "DT");
+  processing_step_sp->setSrcProcessingType(pappso::Axis::y, "RT");
 
   // Now we need to document not the source but the destination. What kind of
   // integration are we about to perform?
 
   if(m_ui.integrateToRtPushButton->isChecked())
     {
-       qDebug() << "Integrating to XIC chromatogram.";
+      qDebug() << "Integrating to XIC chromatogram.";
 
-      processing_step_p->setDestProcessingType("RT");
+      processing_step_sp->setDestProcessingType("RT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
         ->integrateToRt(plottable_p, local_processing_flow);
@@ -389,9 +390,10 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
     {
       qDebug() << "Integrating to dt / rt color map.";
 
-      processing_step_p->setDestProcessingType("DT_RT");
+      processing_step_sp->setDestProcessingType("DT_RT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
         ->integrateToDtRt(plottable_p, local_processing_flow);
@@ -403,21 +405,21 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
     {
       if(m_ui.integrateToMzPushButton->isChecked())
         {
-           qDebug() << "Integrating to mass spectrum.";
+          qDebug() << "Integrating to mass spectrum.";
 
-          processing_step_p->setDestProcessingType("MZ");
+          processing_step_sp->setDestProcessingType("MZ");
         }
       else if(m_ui.integrateToMzRtPushButton->isChecked())
         {
           qDebug() << "Integrating to m/z / rt color map.";
 
-          processing_step_p->setDestProcessingType("MZ_RT");
+          processing_step_sp->setDestProcessingType("MZ_RT");
         }
       else if(m_ui.integrateToDtMzPushButton->isChecked())
         {
           qDebug() << "Integrating to dt / m/z color map.";
 
-          processing_step_p->setDestProcessingType("DT_MZ");
+          processing_step_sp->setDestProcessingType("DT_MZ");
         }
 
       // At this point we need to define how the mass data integrator will
@@ -468,12 +470,14 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
 
       // We finally have mz integ params that we can set to the processing step
       // that we are creating to document this current integration.
-      processing_step_p->setMzIntegrationParams(mz_integration_params);
+      processing_step_sp->setMzIntegrationParams(mz_integration_params);
 
       // And nwo add the new processing step to the local copy of the processing
       // flow, so that we document on top of all the previous steps, also this
       // last one.
-      local_processing_flow.push_back(processing_step_p);
+
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       // qDebug().noquote() << "Pushed back new processing step:"
       //<< processing_step_p->toString();
@@ -499,11 +503,12 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToDtPushButton->isChecked())
     {
-       qDebug() << "Integrating to drift spectrum.";
+      qDebug() << "Integrating to drift spectrum.";
 
-      processing_step_p->setDestProcessingType("DT");
+      processing_step_sp->setDestProcessingType("DT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
         ->integrateToDt(plottable_p, local_processing_flow);
@@ -512,9 +517,10 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
     {
       qDebug() << "Integrating to TIC intensity.";
 
-      processing_step_p->setDestProcessingType("INT");
+      processing_step_sp->setDestProcessingType("INT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BasePlotWnd *>(mp_parentWnd)
         ->integrateToTicIntensity(plottable_p, nullptr, local_processing_flow);
