@@ -67,14 +67,14 @@ TicXicChromDriftSpecColorMapWnd::TicXicChromDriftSpecColorMapWnd(
   const QString &description)
   : BaseColorMapPlotWnd(parent, title, settingsTitle, description)
 {
-  //qDebug() ;
+  // qDebug() ;
 }
 
 
 //! Destruct \c this TicXicChromDriftSpecColorMapWnd instance.
 TicXicChromDriftSpecColorMapWnd::~TicXicChromDriftSpecColorMapWnd()
 {
-  //qDebug() ;
+  // qDebug() ;
 }
 
 
@@ -123,7 +123,7 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
     qualified_mass_spectra_sp,
   const ProcessingFlow &processing_flow)
 {
-   //qDebug().noquote() << "Integrating to dt | rt with processing flow:"
+  // qDebug().noquote() << "Integrating to dt | rt with processing flow:"
   //<< processing_flow.toString();
 
   // Get the ms run data set that for the graph we are going to base the
@@ -133,7 +133,8 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
   if(ms_run_data_set_csp == nullptr)
     qFatal("Cannot be that the pointer is nullptr.");
 
-  // FIXME: BEGIN Sanity check that might be removed when the program is stabilized.
+  // FIXME: BEGIN Sanity check that might be removed when the program is
+  // stabilized.
   std::pair<double, double> range_pair;
 
   bool integration_rt = processing_flow.innermostRange("ANY_RT", range_pair);
@@ -150,7 +151,8 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
     qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
              << "for y axis: " << range_pair.first << "-" << range_pair.second;
 
-  // FIXME: END Sanity check that might be removed when the program is stabilized.
+  // FIXME: END Sanity check that might be removed when the program is
+  // stabilized.
 
   // First prepare a vector of QualifiedMassSpectrumCstSPtr. If the
   // qualified_mass_spectra_sp is not empty, the
@@ -303,14 +305,13 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
   // triggered. We want the signal/slot pairs to be contained to specific
   // objects. Each MassSpecTracePlotWnd::integrateToMz() call must be containeD
   // to a this/mass_data_integrator_task_p specific signal/slot pair.
-  disconnect(
-    this,
+  disconnect(this,
 
-    &TicXicChromDriftSpecColorMapWnd::integrateToDtRtSignal,
+             &TicXicChromDriftSpecColorMapWnd::integrateToDtRtSignal,
 
-    mass_data_integrator_task_p,
+             mass_data_integrator_task_p,
 
-    &MassDataIntegratorTask::integrateToDtRt);
+             &MassDataIntegratorTask::integrateToDtRt);
 }
 
 
@@ -342,7 +343,7 @@ TicXicChromDriftSpecColorMapWnd::finishedIntegratingToDtRt(
 
   // Get a pointer to the double maptrace map that will serve as the data to
   // fill-in the color map.
-  
+
   // The logic here is that in IM-MS experiments, for a given retention time
   // (rt), the might be hundrds of drift time-resolvec mass spectra. So we
   // create a map that relates rt values with a MapTrace, itself relating dt
@@ -352,7 +353,7 @@ TicXicChromDriftSpecColorMapWnd::finishedIntegratingToDtRt(
   // MapTrace, associated with the dt value. That MapTrace is then set the
   // member map that maps the rt value (map key) with the MapTrace (map value).
 
-   std::shared_ptr<std::map<double, pappso::MapTrace>> rt_maptrace_map =
+  std::shared_ptr<std::map<double, pappso::MapTrace>> rt_maptrace_map =
     mass_data_integrator_to_dtrt_p->getRtMapTraceMapSPtr();
 
   // qDebug() << "rt / maptrace map size:" << rt_maptrace_map->size();
@@ -368,16 +369,16 @@ TicXicChromDriftSpecColorMapWnd::finishedIntegratingToDtRt(
   // the minimum/maximum mz value.
 
   pappso::ColorMapPlotConfig color_map_plot_config(
-      // x data kind
+    // x data kind
     pappso::DataKind::rt,
-      // y data kind
+    // y data kind
     pappso::DataKind::dt,
 
-      // x axis scale
+    // x axis scale
     pappso::AxisScale::orig,
-      // y axis scale
+    // y axis scale
     pappso::AxisScale::orig,
-      // z axis scale
+    // z axis scale
     pappso::AxisScale::orig,
 
     mass_data_integrator_to_dtrt_p->getColorMapKeyCellCount(),
@@ -400,7 +401,8 @@ TicXicChromDriftSpecColorMapWnd::finishedIntegratingToDtRt(
 
   ProcessingFlow processing_flow = mass_data_integrator_p->getProcessingFlow();
 
-  //qDebug() << "The processing flow after integration to dt|rt:" << processing_flow.toString();
+  // qDebug() << "The processing flow after integration to dt|rt:" <<
+  // processing_flow.toString();
 
   // Sanity check
   if(ms_run_data_set_csp != processing_flow.getMsRunDataSetCstSPtr())
