@@ -164,11 +164,11 @@ MassSpecDataFileLoader::setQualifiedMassSpectrum(
   const pappso::QualifiedMassSpectrum &qualified_mass_spectrum)
 {
   // qDebug() << "from thread:" << QThread::currentThread()
-  //<< "qualified mass spectrum:" << &qualified_mass_spectrum;
+  // << "qualified mass spectrum:" << &qualified_mass_spectrum;
 
   if(qualified_mass_spectrum.isEmptyMassSpectrum())
     {
-      // qDebug() << "Spectrum has no binary data, returning.";
+      qDebug() << "Spectrum has no binary data, returning.";
       return;
     }
 
@@ -193,12 +193,15 @@ MassSpecDataFileLoader::setQualifiedMassSpectrum(
   // new count.  And emit a textual representation of the current task
   // situation.
 
+  double retention_time = qualified_mass_spectrum_csp->getRtInMinutes();
+
   ++m_setQualifiedMassSpectrumCount;
 
   emit setStatusTextAndCurrentValueSignal(
-    QString("Added %1 spectra over %2")
+    QString("Added %1 spectra over %2 (retention time: %3)")
       .arg(m_setQualifiedMassSpectrumCount)
-      .arg(m_spectrumListSize),
+      .arg(m_spectrumListSize)
+      .arg(retention_time, 0, 'f', 1),
     m_setQualifiedMassSpectrumCount);
 }
 
