@@ -92,13 +92,21 @@ class MsRunDataSet : public QObject
     // By default we use the streamed method to load the data.
     bool isStreamed = true);
 
+  explicit MsRunDataSet(
+    QObject *parent,
+    const pappso::MsRunIdCstSPtr ms_run_id_csp,
+    // By default we use the streamed method to load the data.
+    bool isStreamed = true);
+
   MsRunDataSet(const MsRunDataSet &other);
   ~MsRunDataSet();
 
   void setFileFormat(pappso::MzFormat file_format);
   pappso::MzFormat getFileFormat() const;
 
+  void setMsRunId(pappso::MsRunIdCstSPtr ms_run_id_csp);
   pappso::MsRunIdCstSPtr getMsRunId() const;
+
   pappso::MsRunReaderSPtr getMsRunReaderSPtr();
   pappso::MsRunReaderCstSPtr getMsRunReaderCstSPtr() const;
 
@@ -173,6 +181,8 @@ class MsRunDataSet : public QObject
 
   pappso::MsRunReaderSPtr msp_msRunReader = nullptr;
 
+  pappso::MsRunIdCstSPtr mcsp_msRunId = nullptr;
+
   pappso::MzFormat m_fileFormat = pappso::MzFormat::unknown;
 
   //! Tells if the data are to be or were loaded in streamed mode or not.
