@@ -141,12 +141,12 @@ MsRunDataSetTreeMassDataIntegratorToRt::getMsRunDataSetStats() const
 
 void
 MsRunDataSetTreeMassDataIntegratorToRt::appendProcessingStep(
-  ProcessingStep *processing_step_p)
+  ProcessingStepCstSPtr processing_step_csp)
 {
-  if(processing_step_p == nullptr)
+  if(processing_step_csp == nullptr)
     qFatal("The pointer cannot be nullptr.");
 
-  m_processingFlow.push_back(processing_step_p);
+  m_processingFlow.push_back(processing_step_csp);
 }
 
 
@@ -183,7 +183,7 @@ MsRunDataSetTreeMassDataIntegratorToRt::
   // We need to craft a new processing step, push it back to the processing
   // flow and then call the proper integration function.
 
-  ProcessingStep *step_p = new ProcessingStep(ms_frag_spec);
+  ProcessingStepSPtr step_sp = std::make_shared<ProcessingStep>(ms_frag_spec);
 
   double range_start = mcsp_msRunDataSet->getMsRunDataSetTreeCstSPtr()
                          ->getRootNodes()
@@ -202,26 +202,27 @@ MsRunDataSetTreeMassDataIntegratorToRt::
   pappso::SelectionPolygon selection_polygon;
   selection_polygon.set1D(range_start, range_end);
 
-  step_p->setSelectionPolygon(selection_polygon);
+  step_sp->setSelectionPolygon(selection_polygon);
 
   // qDebug() << "Created 1D selection polygon:"
   //<< step_p->getSelectionPolygon().toString();
 
   // qDebug() << "Is1D:" << step_p->getSelectionPolygon().is1D();
 
-  step_p->setSrcProcessingType(pappso::Axis::x, "FILE_RT");
-  step_p->setDataKind(pappso::Axis::x, pappso::DataKind::rt);
+  step_sp->setSrcProcessingType(pappso::Axis::x, "FILE_RT");
+  step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::rt);
 
-  step_p->setSrcProcessingType(pappso::Axis::y, "NOT_SET");
-  step_p->setDataKind(pappso::Axis::y, pappso::DataKind::unset);
+  step_sp->setSrcProcessingType(pappso::Axis::y, "NOT_SET");
+  step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::unset);
 
   // Now document the destination processing type:
-  step_p->setDestProcessingType("RT");
+  step_sp->setDestProcessingType("RT");
 
   // At this point we have document all the necessary to perform the
   // integration.
 
-  m_processingFlow.push_back(step_p);
+  // There should be auto conversio from non-const to const.
+  m_processingFlow.push_back(step_sp);
 
   // We need to clear the map trace!
   m_mapTrace.clear();
@@ -468,7 +469,7 @@ MsRunDataSetTreeMassDataIntegratorToRt::
   std::const_pointer_cast<MsRunDataSet>(mcsp_msRunDataSet)
     ->setMsRunDataSetStats(ms_run_data_set_stats_merge);
 
-  //qDebug().noquote() << mcsp_msRunDataSet->getMsRunDataSetStats().toString();
+  // qDebug().noquote() << mcsp_msRunDataSet->getMsRunDataSetStats().toString();
 
   std::chrono::system_clock::time_point chrono_end_time =
     std::chrono::system_clock::now();
@@ -506,9 +507,9 @@ MsRunDataSetTreeMassDataIntegratorToRt::integrateToRt()
     qFatal("The processing flow cannot be empty. Program aborted.");
 
   // Get the most recent step that holds all the specifics of this integration.
-  const ProcessingStep *processing_step_p = m_processingFlow.mostRecentStep();
+  ProcessingStepCstSPtr processing_step_csp = m_processingFlow.mostRecentStep();
 
-  if(!processing_step_p->srcMatches("ANY_RT"))
+  if(!processing_step_csp->srcMatches("ANY_RT"))
     qFatal(
       "There should be one source ProcessingType = ANY_RT. Program aborted.");
 
