@@ -80,7 +80,7 @@ class MsRunDataSetTreeMassDataIntegratorToRt : public MassDataIntegrator
   virtual ~MsRunDataSetTreeMassDataIntegratorToRt();
 
   ProcessingFlow getProcessingFlow() const;
-  void appendProcessingStep(ProcessingStep *processing_step_p);
+  void appendProcessingStep(ProcessingStepCstSPtr processing_step_csp);
 
   const MsRunDataSetStats &getMsRunDataSetStats() const;
 
