@@ -65,21 +65,19 @@ ProcessingFlow::ProcessingFlow(MsRunDataSetCstSPtr ms_run_data_set_csp)
 }
 
 ProcessingFlow::ProcessingFlow(const ProcessingFlow &other)
-  : std::vector<msxps::minexpert::ProcessingStep *>(),
+  : std::vector<msxps::minexpert::ProcessingStepCstSPtr>(),
     mcsp_msRunDataSet(other.mcsp_msRunDataSet),
     m_defaultMzIntegrationParams(other.m_defaultMzIntegrationParams),
     m_defaultMsFragmentationSpec(other.m_defaultMsFragmentationSpec)
 {
-  for(auto &&step_p : other)
-    push_back(new ProcessingStep(*step_p));
-
+  assign(other.begin(), other.end());
   m_filterMap = other.m_filterMap;
 }
 
 
 ProcessingFlow::~ProcessingFlow()
 {
-  // Free all the steps in the vector, the objects are deleted.
+  // Now clear the vector.
   clear();
 }
 
@@ -148,15 +146,12 @@ ProcessingFlow::getDefaultMsFragmentationSpec() const
 }
 
 
-std::vector<ProcessingStep *>
+std::vector<ProcessingStepCstSPtr>
 ProcessingFlow::steps()
 {
-  std::vector<ProcessingStep *> steps;
+  std::vector<ProcessingStepCstSPtr> steps;
 
-  for(auto &&step : *this)
-    {
-      steps.push_back(new ProcessingStep(*step));
-    }
+  steps.assign(begin(), end());
 
   return steps;
 }
@@ -219,7 +214,7 @@ bool
 ProcessingFlow::innermostRange(
   ProcessingType src_processing_type_mask,
   std::pair<double, double> &out_range,
-  std::vector<ProcessingStep> *out_processing_steps_p,
+  std::vector<ProcessingStepCstSPtr> *out_processing_steps_p,
   bool store_only_2d_steps,
   bool store_only_skewed) const
 {
@@ -246,18 +241,19 @@ ProcessingFlow::innermostRange(
 
   bool is_first_iterated_item = true;
 
-  ProcessingStep *innermost_step_p = nullptr;
+  ProcessingStepCstSPtr innermost_step_csp = nullptr;
 
-  // A ProcessingFlow is a vector of ProcessingStep *.
-  for(auto &&step_p : *this)
+  // A ProcessingFlow is a vector of ProcessingStepCstSPtr.
+
+  for(auto &step_csp : *this)
     {
       // qDebug() << "Iterating in step:" << step_p->toString();
 
       double range_start;
       double range_end;
 
-      ProcessingType iter_x_processing_type = step_p->m_xSrcType;
-      ProcessingType iter_y_processing_type = step_p->m_ySrcType;
+      ProcessingType iter_x_processing_type = step_csp->m_xSrcType;
+      ProcessingType iter_y_processing_type = step_csp->m_ySrcType;
 
       // qDebug() << "Iterating in ProcessingStep of x and y src types:"
       //<< iter_x_processing_type.toBriefDesc() << "and"
@@ -277,7 +273,7 @@ ProcessingFlow::innermostRange(
 
       // Is the currently iterated step mono- or two-dimensional ?
 
-      bool is_2D = step_p->m_selectionPolygon.is2D();
+      bool is_2D = step_csp->m_selectionPolygon.is2D();
 
       if(!is_2D)
         {
@@ -286,7 +282,7 @@ ProcessingFlow::innermostRange(
 
           // qDebug() << "That step is 1D";
 
-          step_p->m_selectionPolygon.rangeX(range_start, range_end);
+          step_csp->m_selectionPolygon.rangeX(range_start, range_end);
 
           if(is_first_iterated_item)
             {
@@ -300,7 +296,7 @@ ProcessingFlow::innermostRange(
                 {
                   // qDebug() << "Even if 1D, setting step as innermost step as
                   // " "requested.";
-                  innermost_step_p = step_p;
+                  innermost_step_csp = step_csp;
                 }
 
               is_first_iterated_item = false;
@@ -334,7 +330,7 @@ ProcessingFlow::innermostRange(
                 {
                   // qDebug() << "Even if 1D, setting step as innermost step as
                   // " "requested.";
-                  innermost_step_p = step_p;
+                  innermost_step_csp = step_csp;
                 }
             }
 
@@ -349,26 +345,26 @@ ProcessingFlow::innermostRange(
           // because we need to know what is the type of the different selection
           // polygon axes.
 
-          if(step_p->m_xSrcType.bitMatches(src_processing_type_mask))
+          if(step_csp->m_xSrcType.bitMatches(src_processing_type_mask))
             {
               // qDebug() << "Step's m_xSrcType.bitMatches"
               //<< src_processing_type_mask.toBriefDesc();
 
               // The x axis is the axis we need to check the innermost range of.
 
-              step_p->m_selectionPolygon.rangeX(range_start, range_end);
+              step_csp->m_selectionPolygon.rangeX(range_start, range_end);
 
               // qDebug() << "Gotten range values:" << range_start << "-"
               //<< range_end;
             }
-          else if(step_p->m_ySrcType.bitMatches(src_processing_type_mask))
+          else if(step_csp->m_ySrcType.bitMatches(src_processing_type_mask))
             {
               // qDebug() << "Step's m_ySrcType.bitMatches"
               //<< src_processing_type_mask.toBriefDesc();
 
               // The y axis is the axis we need to check the innermost range of.
 
-              step_p->m_selectionPolygon.rangeY(range_start, range_end);
+              step_csp->m_selectionPolygon.rangeY(range_start, range_end);
 
               // qDebug() << "Gotten range values:" << range_start << "-"
               //<< range_end;
@@ -385,7 +381,7 @@ ProcessingFlow::innermostRange(
               //<< inner_range_start << "-" << inner_range_end;
 
               // qDebug() << "Setting step as innermost step.";
-              innermost_step_p = step_p;
+              innermost_step_csp = step_csp;
 
               is_first_iterated_item = false;
             }
@@ -418,7 +414,7 @@ ProcessingFlow::innermostRange(
               if(was_one_dimension_inner)
                 {
                   // qDebug() << "Setting step as innermost step.";
-                  innermost_step_p = step_p;
+                  innermost_step_csp = step_csp;
                 }
             }
 
@@ -449,7 +445,7 @@ ProcessingFlow::innermostRange(
     {
       // qDebug() << "The caller wants the innermost step to be stored.";
 
-      if(innermost_step_p != nullptr)
+      if(innermost_step_csp != nullptr)
         {
           // qDebug() << "One innermost step was indeed found.";
 
@@ -461,7 +457,7 @@ ProcessingFlow::innermostRange(
             }
           else
             {
-              if(!innermost_step_p->getSelectionPolygon().isRectangle())
+              if(!innermost_step_csp->getSelectionPolygon().isRectangle())
                 {
                   should_store_the_step_in_the_end = true;
                   // qDebug() << "The caller wants *only* the 2D skewed steps
@@ -494,9 +490,9 @@ ProcessingFlow::innermostRange(
 
       bool was_step_found = false;
 
-      for(auto &&iter_step : *out_processing_steps_p)
+      for(auto &iter_step_csp : *out_processing_steps_p)
         {
-          if(iter_step.m_dateAndTime == innermost_step_p->m_dateAndTime)
+          if(iter_step_csp->m_dateAndTime == innermost_step_csp->m_dateAndTime)
             {
               was_step_found = true;
 
@@ -512,7 +508,7 @@ ProcessingFlow::innermostRange(
           // qDebug() << "The step is actually skewed, so storing it:"
           //<< innermost_step_p->toString();
 
-          out_processing_steps_p->push_back(*innermost_step_p);
+          out_processing_steps_p->push_back(innermost_step_csp);
         }
     }
 
@@ -527,7 +523,7 @@ bool
 ProcessingFlow::innermostRange(
   const QString src_processing_type_mask,
   std::pair<double, double> &out_range,
-  std::vector<ProcessingStep> *out_processing_steps_p,
+  std::vector<ProcessingStepCstSPtr> *out_processing_steps_p,
   bool store_only_2d_steps,
   bool store_only_skewed) const
 {
@@ -608,7 +604,7 @@ ProcessingFlow::greatestMsLevel() const
 }
 
 
-const ProcessingStep *
+ProcessingStepCstSPtr
 ProcessingFlow::oldestStep() const
 {
   // We rely on the QDateTime instance in the steps to check which of
@@ -620,29 +616,29 @@ ProcessingFlow::oldestStep() const
   if(size() == 1)
     return front();
 
-  const ProcessingStep *oldest_step_p = front();
+  ProcessingStepCstSPtr oldest_step_csp = front();
 
   // Seed the temporary date and time with the first step in the
   // vector.
   QDateTime temp_date_time = front()->m_dateAndTime;
 
-  for(std::vector<ProcessingStep *>::const_iterator iterator = begin() + 1;
+  for(std::vector<ProcessingStepCstSPtr>::const_iterator iterator = begin() + 1;
       iterator != end();
       ++iterator)
     {
       // Is the iterated step older than temp_date_time?
       if((*iterator)->m_dateAndTime < temp_date_time)
         {
-          oldest_step_p  = *iterator;
-          temp_date_time = (*iterator)->m_dateAndTime;
+          oldest_step_csp = *iterator;
+          temp_date_time  = (*iterator)->m_dateAndTime;
         }
     }
 
-  return oldest_step_p;
+  return oldest_step_csp;
 }
 
 
-const ProcessingStep *
+ProcessingStepCstSPtr
 ProcessingFlow::mostRecentStep() const
 {
   // We rely on the QDateTime instance in the steps to check which of
@@ -655,7 +651,7 @@ ProcessingFlow::mostRecentStep() const
   if(size() == 1)
     return front();
 
-  const ProcessingStep *most_recent_step_p = nullptr;
+  ProcessingStepCstSPtr most_recent_step_csp = nullptr;
 
   QDateTime date_time;
   date_time.setDate(QDate(1900, 1, 1));
@@ -665,30 +661,31 @@ ProcessingFlow::mostRecentStep() const
       // qDebug();
 
       if(step_p->m_dateAndTime > date_time)
-        most_recent_step_p = step_p;
+        most_recent_step_csp = step_p;
     }
 
-  return most_recent_step_p;
+  return most_recent_step_csp;
 }
 
 
-std::vector<const ProcessingStep *>
+std::vector<ProcessingStepCstSPtr>
 ProcessingFlow::stepsMatchingDestType(const ProcessingType &processing_type,
                                       bool with_valid_fragmentation_spec) const
 {
-  std::vector<const ProcessingStep *> processing_steps;
+  std::vector<ProcessingStepCstSPtr> processing_steps;
 
-  for(auto &&step_p : *this)
+  for(auto &&step_csp : *this)
     {
-      if(step_p->m_destType.bitMatches(processing_type))
+
+      if(step_csp->m_destType.bitMatches(processing_type))
         {
           if(with_valid_fragmentation_spec)
             {
-              if(step_p->getMsFragmentationSpec().isValid())
-                processing_steps.push_back(step_p);
+              if(step_csp->getMsFragmentationSpec().isValid())
+                processing_steps.push_back(step_csp);
             }
           else
-            processing_steps.push_back(step_p);
+            processing_steps.push_back(step_csp);
         }
     }
 
@@ -696,7 +693,7 @@ ProcessingFlow::stepsMatchingDestType(const ProcessingType &processing_type,
 }
 
 
-std::vector<const ProcessingStep *>
+std::vector<ProcessingStepCstSPtr>
 ProcessingFlow::stepsMatchingDestType(const QString &processing_type,
                                       bool with_valid_fragmentation_spec) const
 {
@@ -705,7 +702,7 @@ ProcessingFlow::stepsMatchingDestType(const QString &processing_type,
 }
 
 
-const ProcessingStep *
+ProcessingStepCstSPtr
 ProcessingFlow::closestOlderStep(const QDateTime &date_time) const
 {
   // qDebug() << "comparison date time:" << date_time
@@ -733,9 +730,9 @@ ProcessingFlow::closestOlderStep(const QDateTime &date_time) const
   // Seed the temporary date time with the oldest step's date and
   // time.
 
-  const ProcessingStep *older_step_p = nullptr;
+  ProcessingStepCstSPtr older_step_csp = nullptr;
 
-  for(std::vector<ProcessingStep *>::const_iterator iterator = begin();
+  for(std::vector<ProcessingStepCstSPtr>::const_iterator iterator = begin();
       iterator != end();
       ++iterator)
     {
@@ -747,11 +744,11 @@ ProcessingFlow::closestOlderStep(const QDateTime &date_time) const
           // qDebug() << "iter time is less than comparison date
           // time.";
 
-          if(older_step_p == nullptr)
+          if(older_step_csp == nullptr)
             {
               // First iteration for which the date is less than
               // comparison time.
-              older_step_p = *iterator;
+              older_step_csp = *iterator;
 
               continue;
             }
@@ -760,17 +757,17 @@ ProcessingFlow::closestOlderStep(const QDateTime &date_time) const
           // fine, but is it more recent that the temporaray time ? If
           // so set it as the last older step.
 
-          if((*iterator)->m_dateAndTime > older_step_p->m_dateAndTime)
+          if((*iterator)->m_dateAndTime > older_step_csp->m_dateAndTime)
             {
               // qDebug() << "more than that: iter time is also more
               // recent than " "last itered time.";
 
-              older_step_p = *iterator;
+              older_step_csp = *iterator;
             }
         }
     }
 
-  return older_step_p;
+  return older_step_csp;
 }
 
 
@@ -780,17 +777,17 @@ ProcessingFlow::mostRecentMzIntegrationParams() const
 
   // qDebug() << "*this processing flow:" << this->toString();
 
-  const ProcessingStep *most_recent_step_p = mostRecentStep();
+  ProcessingStepCstSPtr most_recent_step_csp = mostRecentStep();
 
-  if(most_recent_step_p != nullptr)
+  if(most_recent_step_csp != nullptr)
     {
-      if(most_recent_step_p->mpa_mzIntegrationParams != nullptr)
+      if(most_recent_step_csp->mpa_mzIntegrationParams != nullptr)
         {
           // qDebug()
           //<< "Returning immediately the most recent step's mz integ.
           // params.";
 
-          return most_recent_step_p->mpa_mzIntegrationParams;
+          return most_recent_step_csp->mpa_mzIntegrationParams;
         }
     }
   else
@@ -807,10 +804,10 @@ ProcessingFlow::mostRecentMzIntegrationParams() const
     {
       // Get a step older than the most recent step.
 
-      const ProcessingStep *closest_older_step_p =
-        closestOlderStep(most_recent_step_p->m_dateAndTime);
+      const ProcessingStepCstSPtr closest_older_step_csp =
+        closestOlderStep(most_recent_step_csp->m_dateAndTime);
 
-      if(closest_older_step_p != nullptr)
+      if(closest_older_step_csp != nullptr)
         {
           // qDebug()
           //<< "iterating in infinite while loop with closest older
@@ -820,13 +817,13 @@ ProcessingFlow::mostRecentMzIntegrationParams() const
 
           // Found an older step, but check if it has mz integration
           // params set to it.
-          if(closest_older_step_p->mpa_mzIntegrationParams != nullptr)
+          if(closest_older_step_csp->mpa_mzIntegrationParams != nullptr)
             {
               // qDebug() << "Found a step that is closest and that
               // has mz "
               //"integration params.";
 
-              return closest_older_step_p->mpa_mzIntegrationParams;
+              return closest_older_step_csp->mpa_mzIntegrationParams;
             }
           else
             {
