@@ -50,7 +50,7 @@
 /////////////////////// Local includes
 #include "MsRunDataSet.hpp"
 #include "MsFragmentationSpec.hpp"
-
+#include "ProcessingStep.hpp"
 
 namespace msxps
 {
@@ -60,7 +60,7 @@ namespace minexpert
 class ProcessingType;
 class ProcessingStep;
 
-class ProcessingFlow : public std::vector<ProcessingStep *>
+class ProcessingFlow : public std::vector<ProcessingStepCstSPtr>
 {
 
   public:
@@ -72,9 +72,10 @@ class ProcessingFlow : public std::vector<ProcessingStep *>
 
   ProcessingFlow &operator=(const ProcessingFlow &other);
 
-  std::vector<ProcessingStep *> steps();
+  std::vector<ProcessingStepCstSPtr> steps();
 
-  const std::map<QString, pappso::FilterNameInterfaceCstSPtr> &getFilterMap() const;
+  const std::map<QString, pappso::FilterNameInterfaceCstSPtr> &
+  getFilterMap() const;
 
   void addFilter(pappso::FilterNameInterfaceCstSPtr filter_csp);
   std::size_t removeFilter(const QString &filter_name);
@@ -84,30 +85,30 @@ class ProcessingFlow : public std::vector<ProcessingStep *>
   bool
   innermostRange(ProcessingType src_processing_type_mask,
                  std::pair<double, double> &out_range,
-                 std::vector<ProcessingStep> *out_processing_steps_p = nullptr,
-                 bool store_only_2d_steps                            = true,
-                 bool store_only_skewed = true) const;
+                 std::vector<ProcessingStepCstSPtr> *out_processing_steps_p,
+                 bool store_only_2d_steps = true,
+                 bool store_only_skewed   = true) const;
 
-  bool
-  innermostRange(const QString src_processing_type_mask,
-                 std::pair<double, double> &out_range,
-                 std::vector<ProcessingStep> *out_processing_steps_p = nullptr,
-                 bool store_only_2d_steps                            = true,
-                 bool store_only_skewed = true) const;
+  bool innermostRange(
+    const QString src_processing_type_mask,
+    std::pair<double, double> &out_range,
+    std::vector<ProcessingStepCstSPtr> *out_processing_steps_p = nullptr,
+    bool store_only_2d_steps                                   = true,
+    bool store_only_skewed                                     = true) const;
 
   bool hasOnly1DSteps();
 
   size_t greatestMsLevel() const;
 
-  const ProcessingStep *oldestStep() const;
-  const ProcessingStep *closestOlderStep(const QDateTime &date_time) const;
-  const ProcessingStep *mostRecentStep() const;
+  ProcessingStepCstSPtr oldestStep() const;
+  ProcessingStepCstSPtr closestOlderStep(const QDateTime &date_time) const;
+  ProcessingStepCstSPtr mostRecentStep() const;
 
-  std::vector<const ProcessingStep *>
+  std::vector<ProcessingStepCstSPtr>
   stepsMatchingDestType(const ProcessingType &processing_type,
                         bool with_valid_fragmentation_spec = false) const;
 
-  std::vector<const ProcessingStep *>
+  std::vector<ProcessingStepCstSPtr>
   stepsMatchingDestType(const QString &processing_type,
                         bool with_valid_fragmentation_spec = false) const;
 
