@@ -219,13 +219,12 @@ ProcessingType::registerProcessingCompositeTypes(
 
       if(brief_desc.isEmpty())
         {
-          //qDebug() << "brief_desc is empty, continuing.";
+          // qDebug() << "brief_desc is empty, continuing.";
           continue;
         }
 
       using Pair = std::pair<std::bitset<32>, ProcessingTypeStringPair>;
-      using Map =
-        std::unordered_map<std::bitset<32>, ProcessingTypeStringPair>;
+      using Map = std::unordered_map<std::bitset<32>, ProcessingTypeStringPair>;
       using Iterator = Map::const_iterator;
 
       Iterator found_iterator =
@@ -253,10 +252,10 @@ ProcessingType::registerProcessingCompositeTypes(
 
   ProcessingType::processingTypeRegistry.insert(
     std::pair<std::bitset<32>, ProcessingTypeStringPair>(final_bit_set,
-                                                          dest_desc_pair));
+                                                         dest_desc_pair));
 
-  //qDebug() << "Inserted new bit_set:" << dest_desc_pair << "with value:"
-           //<< QString::fromStdString(final_bit_set.to_string());
+  // qDebug() << "Inserted new bit_set:" << dest_desc_pair << "with value:"
+  //<< QString::fromStdString(final_bit_set.to_string());
 }
 
 
@@ -543,7 +542,7 @@ ProcessingType::bitMatches(const ProcessingType &processing_type,
   std::bitset<32> test_bit_set = processing_type.bitSet();
 
   std::bitset<32> res_bit_set = test_bit_set & mask;
-  bool res                     = res_bit_set == test_bit_set;
+  bool res                    = res_bit_set == test_bit_set;
 
   // qDebug() << "res_bit_set:" <<
   // QString::fromStdString(res_bit_set.to_string())
