@@ -95,7 +95,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::
     mcsp_qualifiedMassSpectraToIntegrateVector(
       other.mcsp_qualifiedMassSpectraToIntegrateVector)
 {
-  //qDebug();
+  // qDebug();
   m_processingFlow.setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
   setInnermostRanges();
 }
@@ -506,18 +506,18 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsLevel(
     {
       if(spectrum_ms_level != greatest_ms_level)
         {
-          //qDebug().noquote()
-            //<< "Spectrum ms level:" << spectrum_ms_level
-            //<< "does *not* match greatest ms level:" << greatest_ms_level;
+          // qDebug().noquote()
+          //<< "Spectrum ms level:" << spectrum_ms_level
+          //<< "does *not* match greatest ms level:" << greatest_ms_level;
 
           return false;
         }
-      //else
-        //{
-          //qDebug().noquote()
-            //<< "Spectrum ms level:" << spectrum_ms_level
-            //<< "*does* match greatest ms level:" << greatest_ms_level;
-        //}
+      // else
+      //{
+      // qDebug().noquote()
+      //<< "Spectrum ms level:" << spectrum_ms_level
+      //<< "*does* match greatest ms level:" << greatest_ms_level;
+      //}
     }
   // else
   //{
@@ -526,7 +526,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsLevel(
   // Just go on, we do take into consideration any MS level.
   //}
 
-  //qDebug() << "Returning true.";
+  // qDebug() << "Returning true.";
 
   return true;
 }
@@ -534,7 +534,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsLevel(
 
 bool
 QualifiedMassSpectrumVectorMassDataIntegrator::checkMsFragmentation(
-  const ProcessingStep &processing_step,
+  ProcessingStepCstSPtr processing_step_csp,
   pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp)
 {
   // qDebug();
@@ -546,12 +546,13 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsFragmentation(
     qFatal("Cannot be nullptr");
 
   const MsFragmentationSpec fragmentation_spec =
-    processing_step.getMsFragmentationSpec();
+    processing_step_csp->getMsFragmentationSpec();
 
   if(fragmentation_spec.isValid())
     {
-      //qDebug().noquote() << "ProcessingSpec's MsFragmentationSpec *is*  valid:"
-                         //<< fragmentation_spec.toString();
+      // qDebug().noquote() << "ProcessingSpec's MsFragmentationSpec *is*
+      // valid:"
+      //<< fragmentation_spec.toString();
 
       // Check if the fragmentation spec contains at least one
       // precursor. There are not necessarily because the fragmentation
@@ -611,15 +612,15 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsFragmentation(
             return false;
         }
     }
-  //else
-    //{
-      //// Else, fragmentation is not a criterion for filtering data. So
-      //// go on.
+  // else
+  //{
+  //// Else, fragmentation is not a criterion for filtering data. So
+  //// go on.
 
-      //qDebug() << "The fragmentation spec is *not* valid. This means that the "
-                  //"check succeeds because fragmentation is not a criterion for "
-                  //"the filtering of the data.";
-    //}
+  // qDebug() << "The fragmentation spec is *not* valid. This means that the "
+  //"check succeeds because fragmentation is not a criterion for "
+  //"the filtering of the data.";
+  //}
 
   return true;
 }
@@ -642,9 +643,9 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsFragmentation(
 
   // A processing flow contains a number of processing steps.
 
-  for(auto &step : m_processingFlow)
+  for(auto &&step_csp : m_processingFlow)
     {
-      if(!checkMsFragmentation(*step, qualified_mass_spectrum_csp))
+      if(!checkMsFragmentation(step_csp, qualified_mass_spectrum_csp))
         return false;
     }
 
@@ -655,7 +656,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsFragmentation(
 void
 QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
 {
-  //qDebug();
+  // qDebug();
 
   m_innermostSteps2D.clear();
 
@@ -693,8 +694,8 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
   if(m_processingFlow.innermostRange(
        "ANY_DT", range_pair, &m_innermostSteps2D, true, true))
     {
-      //qDebug() << "innermost DT range:" << range_pair.first << "-"
-               //<< range_pair.second;
+      // qDebug() << "innermost DT range:" << range_pair.first << "-"
+      //<< range_pair.second;
 
       m_dtRange.first  = range_pair.first;
       m_dtRange.second = range_pair.second;
@@ -708,8 +709,8 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
   if(m_processingFlow.innermostRange(
        "ANY_MZ", range_pair, &m_innermostSteps2D, true, true))
     {
-      //qDebug() << "innermost MZ range:" << range_pair.first << "-"
-               //<< range_pair.second;
+      // qDebug() << "innermost MZ range:" << range_pair.first << "-"
+      //<< range_pair.second;
 
       m_mzRange.first  = range_pair.first;
       m_mzRange.second = range_pair.second;
@@ -723,8 +724,8 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
   if(m_processingFlow.innermostRange(
        "ANY_RT", range_pair, &m_innermostSteps2D, true, true))
     {
-      //qDebug() << "innermost RT range:" << range_pair.first << "-"
-               //<< range_pair.second;
+      // qDebug() << "innermost RT range:" << range_pair.first << "-"
+      //<< range_pair.second;
 
       m_rtRange.first  = range_pair.first;
       m_rtRange.second = range_pair.second;
@@ -740,8 +741,8 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
         "single step with a retention range-specifying step.");
     }
 
-  //qDebug() << "The m_innermostSteps2D has now" << m_innermostSteps2D.size()
-           //<< "steps";
+  // qDebug() << "The m_innermostSteps2D has now" << m_innermostSteps2D.size()
+  //<< "steps";
 }
 
 
@@ -749,10 +750,10 @@ std::size_t
 QualifiedMassSpectrumVectorMassDataIntegrator::fillInSelectionPolygonSpecs(
   std::vector<pappso::SelectionPolygonSpec> &selection_polygon_specs)
 {
-  //qDebug()
-    //<< "Fill in the selection polygon specs (MZ-related stuff) vector from "
-       //"m_innermostSteps2D with size:"
-    //<< m_innermostSteps2D.size();
+  // qDebug()
+  //<< "Fill in the selection polygon specs (MZ-related stuff) vector from "
+  //"m_innermostSteps2D with size:"
+  //<< m_innermostSteps2D.size();
 
   // This function is responsible for configuring the selection polygon specs by
   // looking at m_innermostSteps2D steps that contains MZ data king. These specs
@@ -761,81 +762,85 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInSelectionPolygonSpecs(
   // abide by selection polygons that are not rectangle but are oblique, or
   // skewed.
 
-  for(auto &&step : m_innermostSteps2D)
+  for(auto &&step_csp : m_innermostSteps2D)
     {
-      if(step.getSelectionPolygon().isRectangle())
+      if(step_csp->getSelectionPolygon().isRectangle())
         {
           // The selection polygon is rectangle, which means that the ranges
           // extracted from the processing flow at construction time are fully
           // sufficient to characterize the combination work.
 
-          //qDebug() << "Currently iterated step's selection polygon *is* "
-                      //"rectangle. Skipping it."
-                   //<< step.toString();
+          // qDebug() << "Currently iterated step's selection polygon *is* "
+          //"rectangle. Skipping it."
+          //<< step.toString();
 
           continue;
         }
 
-      //qDebug() << "Iterating in inner most step 2D:" << step.toString();
+      // qDebug() << "Iterating in inner most step 2D:" << step.toString();
 
       // There are two kinds of processing types of interest: DT_MZ_TO_ANY and
       // MZ_RT_TO_ANY.
 
-      if(step.getSrcProcessingType(pappso::Axis::x).bitMatches("MZ"))
+      if(step_csp->getSrcProcessingType(pappso::Axis::x).bitMatches("MZ"))
         {
-          //qDebug() << "Step x source type matches MZ";
+          // qDebug() << "Step x source type matches MZ";
 
-          if(step.getSrcProcessingType(pappso::Axis::y).bitMatches("DT"))
+          if(step_csp->getSrcProcessingType(pappso::Axis::y).bitMatches("DT"))
             {
-              //qDebug() << "We are handling a DT_MZ step source type";
+              // qDebug() << "We are handling a DT_MZ step source type";
 
               // We want the selection polygon to have x:DT and y:MZ.
 
               selection_polygon_specs.push_back(pappso::SelectionPolygonSpec(
-                step.getSelectionPolygon().transpose(), pappso::DataKind::dt));
+                step_csp->getSelectionPolygon().transpose(),
+                pappso::DataKind::dt));
             }
-          else if(step.getSrcProcessingType(pappso::Axis::y).bitMatches("RT"))
+          else if(step_csp->getSrcProcessingType(pappso::Axis::y)
+                    .bitMatches("RT"))
             {
-              //qDebug() << "We are handling a MZ_RT step source type";
+              // qDebug() << "We are handling a MZ_RT step source type";
 
               // We want the selection polygon to have x:RT and y:MZ.
 
               selection_polygon_specs.push_back(pappso::SelectionPolygonSpec(
-                step.getSelectionPolygon().transpose(), pappso::DataKind::rt));
+                step_csp->getSelectionPolygon().transpose(),
+                pappso::DataKind::rt));
             }
           else
             qFatal("Programming error.");
         }
-      else if(step.getSrcProcessingType(pappso::Axis::y).bitMatches("MZ"))
+      else if(step_csp->getSrcProcessingType(pappso::Axis::y).bitMatches("MZ"))
         {
-          //qDebug() << "Step y source type matches MZ";
+          // qDebug() << "Step y source type matches MZ";
 
-          if(step.getSrcProcessingType(pappso::Axis::x).bitMatches("DT"))
+          if(step_csp->getSrcProcessingType(pappso::Axis::x).bitMatches("DT"))
             {
-              //qDebug() << "We are handling a DT_MZ step source type";
+              // qDebug() << "We are handling a DT_MZ step source type";
 
               // We want the selection polygon to have x:DT and y:MZ.
 
               selection_polygon_specs.push_back(pappso::SelectionPolygonSpec(
-                step.getSelectionPolygon(), pappso::DataKind::dt));
+                step_csp->getSelectionPolygon(), pappso::DataKind::dt));
             }
-          else if(step.getSrcProcessingType(pappso::Axis::x).bitMatches("RT"))
+          else if(step_csp->getSrcProcessingType(pappso::Axis::x)
+                    .bitMatches("RT"))
             {
-              //qDebug() << "We are handling a MZ_RT step source type";
+              // qDebug() << "We are handling a MZ_RT step source type";
 
               // We want the selection polygon to have x:RT and y:MZ.
 
               selection_polygon_specs.push_back(pappso::SelectionPolygonSpec(
-                step.getSelectionPolygon(), pappso::DataKind::rt));
+                step_csp->getSelectionPolygon(), pappso::DataKind::rt));
             }
           else
             qFatal("Programming error.");
         }
-      //else
-        //qDebug() << "The step a no source type involving MZ data.";
+      // else
+      // qDebug() << "The step a no source type involving MZ data.";
     }
   // End of
-  // for(auto &&step : m_innermostSteps2D)
+  // for(auto &&step_csp: m_innermostSteps2D)
 
   return selection_polygon_specs.size();
 }
@@ -855,18 +860,18 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkInnermostDtRt2DSteps(
   // Now see if we have to also account for 2D selection skewed polygons
   // involving dt and rt.
 
-  for(auto &&step : m_innermostSteps2D)
+  for(auto &&step_csp : m_innermostSteps2D)
     {
       // qDebug() << "Iterating in step:" << step.toString();
 
       // A skewed selection polygon was found.
 
-      if(step.getSrcProcessingType(pappso::Axis::x).bitMatches("DT") &&
-         step.getSrcProcessingType(pappso::Axis::y).bitMatches("RT"))
+      if(step_csp->getSrcProcessingType(pappso::Axis::x).bitMatches("DT") &&
+         step_csp->getSrcProcessingType(pappso::Axis::y).bitMatches("RT"))
         {
           // That had DT and RT axes.
 
-          if(!step.getSelectionPolygon().contains(QPointF(dt, rt)))
+          if(!step_csp->getSelectionPolygon().contains(QPointF(dt, rt)))
             {
               // qDebug() << "Checking step:" << step.toString()
               //<< "for qualified mass spectrum with dt|rt:" << dt << "|"
@@ -878,14 +883,15 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkInnermostDtRt2DSteps(
           //<< "for qualified mass spectrum with dt|rt:" << dt << "|"
           //<< rt << "succeeded.";
         }
-      else if(step.getSrcProcessingType(pappso::Axis::x).bitMatches("RT") &&
-              step.getSrcProcessingType(pappso::Axis::y).bitMatches("DT"))
+      else if(step_csp->getSrcProcessingType(pappso::Axis::x)
+                .bitMatches("RT") &&
+              step_csp->getSrcProcessingType(pappso::Axis::y).bitMatches("DT"))
         {
           // That had DT and RT axes.
 
           qWarning() << "The selection polygon should have x:DT and y:RT";
 
-          if(!step.getSelectionPolygon().contains(QPointF(rt, dt)))
+          if(!step_csp->getSelectionPolygon().contains(QPointF(rt, dt)))
             {
               // qDebug() << "Checking step:" << step.toString()
               //<< "for qualified mass spectrum with dt|rt:" << dt << "|"
@@ -911,7 +917,7 @@ bool
 QualifiedMassSpectrumVectorMassDataIntegrator::checkDtRange(
   pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp)
 {
-  //qDebug();
+  // qDebug();
 
   // We are asked to check if the mass spectrum matches the DT range. This
   // means that we can quickly check that agains all DT range that was
@@ -943,7 +949,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkDtRange(
 
   if(!(dt >= m_dtRange.first && dt <= m_dtRange.second))
     {
-      //qDebug() << "Returning false on the check of the dt range.";
+      // qDebug() << "Returning false on the check of the dt range.";
       return false;
     }
 
@@ -958,7 +964,7 @@ bool
 QualifiedMassSpectrumVectorMassDataIntegrator::checkRtRange(
   pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp)
 {
-  //qDebug();
+  // qDebug();
 
   // We are asked to check if the mass spectrum matches the RT range. This
   // means that we can quickly check that agains all RT range that was
