@@ -204,11 +204,11 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrate()
   if(!m_processingFlow.size())
     qFatal("The processing flow cannot be empty. Program aborted.");
 
-  const ProcessingStep *last_processing_step =
+  ProcessingStepCstSPtr last_processing_step_csp =
     m_processingFlow.mostRecentStep();
 
   ProcessingType last_processing_type =
-    last_processing_step->getDestProcessingType();
+    last_processing_step_csp->getDestProcessingType();
 
   // We need to know what kind of integration we deal with here, rt_mz or dt_mz
   // because we have to store it so that after the computation is performed, the
@@ -387,7 +387,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
 
   emit setProgressBarMaxValueSignal(mass_spectra_count);
 
-  // qDebug() << "Starting the iteration in the visitors.";
+  qDebug() << "Starting the iteration in the visitors.";
+  qDebug() << "Number of teams:" << omp_get_num_teams();
 
   omp_set_num_threads(iterators.size());
 #pragma omp parallel for ordered
@@ -779,7 +780,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
   // We need this in some places, for debugging the bin creation and the mass
   // spectrum combination.
-  //QString debug_string = "";
+  // QString debug_string = "";
 
   // qDebug() << "Now filling-in the selectionpolygonspecs.";
 
@@ -797,8 +798,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
   pappso::MzIntegrationParams local_mz_integration_params =
     m_processingFlow.getDefaultMzIntegrationParams();
 
-  //qDebug().noquote() << "Starting integration with mz integration params:"
-                     //<< local_mz_integration_params.toString();
+  // qDebug().noquote() << "Starting integration with mz integration params:"
+  //<< local_mz_integration_params.toString();
 
   // Instanciate a plus combiner that will be used as a template for all the
   // combiners operating concurrently below. Note that because we are computing
@@ -826,23 +827,23 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
         mcsp_msRunDataSet->getMsRunDataSetStats().m_maxMz);
     }
 
-  //qDebug() << "Now starting creation of the bins.";
+  // qDebug() << "Now starting creation of the bins.";
 
   // Now we can create the bins!
   std::vector<double> bins = local_mz_integration_params.createBins();
 
-  //debug_string = QString(
-                   //"Number of bins: %1\n"
-                   //"First bins: %2 %3 %4 -- Last bins: %5 %6 %7\n")
-                   //.arg(bins.size())
-                   //.arg(bins[0], 0, 'f', 6)
-                   //.arg(bins[1], 0, 'f', 6)
-                   //.arg(bins[2], 0, 'f', 6)
-                   //.arg(bins[bins.size() - 3], 0, 'f', 6)
-                   //.arg(bins[bins.size() - 2], 0, 'f', 6)
-                   //.arg(bins[bins.size() - 1], 0, 'f', 6);
+  // debug_string = QString(
+  //"Number of bins: %1\n"
+  //"First bins: %2 %3 %4 -- Last bins: %5 %6 %7\n")
+  //.arg(bins.size())
+  //.arg(bins[0], 0, 'f', 6)
+  //.arg(bins[1], 0, 'f', 6)
+  //.arg(bins[2], 0, 'f', 6)
+  //.arg(bins[bins.size() - 3], 0, 'f', 6)
+  //.arg(bins[bins.size() - 2], 0, 'f', 6)
+  //.arg(bins[bins.size() - 1], 0, 'f', 6);
 
-  //qDebug().noquote() << debug_string;
+  // qDebug().noquote() << debug_string;
 
   template_plus_combiner.setBins(bins);
 
@@ -1015,14 +1016,14 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
           if(m_lastIntegrationDataKind == pappso::DataKind::rt)
             {
               first_key = rt_value;
-              //qDebug() << "The dt|rt key is actually a RT key with value:"
-                       //<< first_key;
+              // qDebug() << "The dt|rt key is actually a RT key with value:"
+              //<< first_key;
             }
           else if(m_lastIntegrationDataKind == pappso::DataKind::dt)
             {
               first_key = dt_value;
-              //qDebug() << "The dt|rt key is actually a DT key with value:"
-                       //<< first_key;
+              // qDebug() << "The dt|rt key is actually a DT key with value:"
+              //<< first_key;
             }
           else
             qFatal("Programming error.");
@@ -1044,7 +1045,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
           if(!std::isnan(m_mzRange.first) && !std::isnan(m_mzRange.second))
             {
-              //qDebug() << "There appears to be an m/z-based filtering need.";
+              // qDebug() << "There appears to be an m/z-based filtering need.";
 
               pappso::FilterResampleKeepXRange the_keep_filter(
                 m_mzRange.first, m_mzRange.second);
@@ -1054,8 +1055,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
           if(selection_polygon_specs.size())
             {
-              //qDebug() << "There appears to be an selection polygon-based "
-                          //"filtering need.";
+              // qDebug() << "There appears to be an selection polygon-based "
+              //"filtering need.";
 
               pappso::FilterResampleKeepPointInPolygon the_polygon_filter(
                 selection_polygon_specs);
@@ -1094,19 +1095,19 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
               mass_spectrum_plus_combiner.combine(
                 double_maptrace_map_iterator->second, filtered_trace);
 
-              //QString debug_string =
-                //QString(
-                  //"The current combination MapTrace's first element: (%1,%2)\n")
-                  //.arg(double_maptrace_map_iterator->second.begin()->first,
-                       //0,
-                       //'f',
-                       //6)
-                  //.arg(double_maptrace_map_iterator->second.begin()->second,
-                       //0,
-                       //'f',
-                       //6);
+              // QString debug_string =
+              // QString(
+              //"The current combination MapTrace's first element: (%1,%2)\n")
+              //.arg(double_maptrace_map_iterator->second.begin()->first,
+              // 0,
+              //'f',
+              // 6)
+              //.arg(double_maptrace_map_iterator->second.begin()->second,
+              // 0,
+              //'f',
+              // 6);
 
-              //qDebug().noquote() << debug_string;
+              // qDebug().noquote() << debug_string;
             }
           else
             {
@@ -1124,16 +1125,16 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
               pappso::MapTrace map_trace;
 
-              // 20220812 See issue #6 at 
+              // 20220812 See issue #6 at
               // https://gitlab.com/msxpertsuite/minexpert2/-/issues/6
               // Where Kevin Hooijschuur explains that with
               // multiplexed/demultiplexed mobility data from the Agilent 6560
               // IMS-QTOF instrument, the color map that is computed is kind of
-              // blurred. 
+              // blurred.
 
               // I discovered that the example file that Kevin provided me with,
               // produced a final color map with a number of cells for the m/z
-              // dimension that did not match the number of bins. 
+              // dimension that did not match the number of bins.
               //
               // I thus understood that that might be the problem and decided to
               // force the final color map to have as many cells in the m/z
@@ -1146,16 +1147,16 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
               mass_spectrum_plus_combiner.combine(map_trace, filtered_trace);
 
-              //QString debug_string =
-                //QString(
-                  //"The brand new rt|dt value: %1 combination MapTrace's first "
-                  //"element: "
-                  //"(%2,%3)\n")
-                  //.arg(first_key)
-                  //.arg(map_trace.begin()->first, 0, 'f', 6)
-                  //.arg(map_trace.begin()->second, 0, 'f', 6);
+              // QString debug_string =
+              // QString(
+              //"The brand new rt|dt value: %1 combination MapTrace's first "
+              //"element: "
+              //"(%2,%3)\n")
+              //.arg(first_key)
+              //.arg(map_trace.begin()->first, 0, 'f', 6)
+              //.arg(map_trace.begin()->second, 0, 'f', 6);
 
-              //qDebug().noquote() << debug_string;
+              // qDebug().noquote() << debug_string;
 
               // Finally, store in the map, the map_trace along with its
               // first_key.
@@ -1212,18 +1213,18 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
   std::vector<double> local_bins = mass_spectrum_plus_combiner.getBins();
 
-  //debug_string = QString(
-                   //"Number of bins: %1\n"
-                   //"First bins: %2 %3 %4 -- Last bins: %5 %6 %7\n")
-                   //.arg(bins.size())
-                   //.arg(bins[0], 0, 'f', 6)
-                   //.arg(bins[1], 0, 'f', 6)
-                   //.arg(bins[2], 0, 'f', 6)
-                   //.arg(bins[bins.size() - 3], 0, 'f', 6)
-                   //.arg(bins[bins.size() - 2], 0, 'f', 6)
-                   //.arg(bins[bins.size() - 1], 0, 'f', 6);
+  // debug_string = QString(
+  //"Number of bins: %1\n"
+  //"First bins: %2 %3 %4 -- Last bins: %5 %6 %7\n")
+  //.arg(bins.size())
+  //.arg(bins[0], 0, 'f', 6)
+  //.arg(bins[1], 0, 'f', 6)
+  //.arg(bins[2], 0, 'f', 6)
+  //.arg(bins[bins.size() - 3], 0, 'f', 6)
+  //.arg(bins[bins.size() - 2], 0, 'f', 6)
+  //.arg(bins[bins.size() - 1], 0, 'f', 6);
 
-  //qDebug().noquote() << debug_string;
+  // qDebug().noquote() << debug_string;
 
   int iter = 0;
 
@@ -1335,19 +1336,19 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
   // qDebug().noquote() << debug_string;
 
-  //for(auto iter = m_doubleMapTraceMapSPtr->begin();
-      //iter != m_doubleMapTraceMapSPtr->end();
-      //++iter)
-    //{
-      //debug_string =
-        //QString(
-          //"For the last key (rt or dt) value (%1) of the double|maptrace map, "
-          //"this is the MapTrace content: %2\n\n")
-          //.arg(iter->first)
-          //.arg(iter->second.toString());
+  // for(auto iter = m_doubleMapTraceMapSPtr->begin();
+  // iter != m_doubleMapTraceMapSPtr->end();
+  //++iter)
+  //{
+  // debug_string =
+  // QString(
+  //"For the last key (rt or dt) value (%1) of the double|maptrace map, "
+  //"this is the MapTrace content: %2\n\n")
+  //.arg(iter->first)
+  //.arg(iter->second.toString());
 
-      //qDebug().noquote() << debug_string;
-    //}
+  // qDebug().noquote() << debug_string;
+  //}
 
   m_colorMapMinKey = m_doubleMapTraceMapSPtr->begin()->first;
   m_colorMapMaxKey = m_doubleMapTraceMapSPtr->rbegin()->first;
@@ -1356,10 +1357,10 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
   m_colorMapMzCellCount = std::numeric_limits<double>::min();
 
-  //qDebug() << "Initial data to configure the color map:"
-           //<< "m_colorMapMinKey: " << m_colorMapMinKey << "m_colorMapMaxKey"
-           //<< m_colorMapMaxKey << "m_colorMapKeyCellCount"
-           //<< m_colorMapKeyCellCount;
+  // qDebug() << "Initial data to configure the color map:"
+  //<< "m_colorMapMinKey: " << m_colorMapMinKey << "m_colorMapMaxKey"
+  //<< m_colorMapMaxKey << "m_colorMapKeyCellCount"
+  //<< m_colorMapKeyCellCount;
 
   for(auto &&key_maptrace_pair : *m_doubleMapTraceMapSPtr)
     {
@@ -1378,11 +1379,11 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
         m_colorMapMaxMz = map_trace.rbegin()->first;
     }
 
-  //qDebug() << "At the end of the map data scrutinization, the following data "
-              //"have emerged"
-           //<< "m_colorMapMinMz:" << m_colorMapMinMz
-           //<< "m_colorMapMaxMz:" << m_colorMapMaxMz
-           //<< "m_colorMapMzCellCount:" << m_colorMapMzCellCount;
+  // qDebug() << "At the end of the map data scrutinization, the following data
+  // " "have emerged"
+  //<< "m_colorMapMinMz:" << m_colorMapMinMz
+  //<< "m_colorMapMaxMz:" << m_colorMapMaxMz
+  //<< "m_colorMapMzCellCount:" << m_colorMapMzCellCount;
 
   return;
 }
